@@ -4,7 +4,7 @@ utils::globalVariables(c("vl", "time", "id",
                          "calculation", "model", "Model",
                          "Included",
                          "Param", "param", "estimate",
-                         "A", "B", "delta", "gamma", "Bhat", "gammahat", "omega",
+                         "A", "B", "delta", "gamma", "Bhat", "gammahat", "A_b", "delta_b",
                          "ShortLifespan", "LongLifespan", "SingleLifespan",
                          "LongLifespanNonProductive", "ShortLifespanProductive", "ShortLifespanNonProductive",
                          "Median", "SD",
